summaryrefslogtreecommitdiffstats
path: root/chrome/browser/gtk/browser_titlebar.h
diff options
context:
space:
mode:
authortc@google.com <tc@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2009-08-05 21:09:45 +0000
committertc@google.com <tc@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2009-08-05 21:09:45 +0000
commite1e4b6e8810a0fc7193ac9a55ad14588a2fff4d1 (patch)
tree73b6b47b1507e14f6aaa12793f0663ed29a913c4 /chrome/browser/gtk/browser_titlebar.h
parentc256c0b0e7a2ca6401528b33b325cb19a981762b (diff)
downloadchromium_src-e1e4b6e8810a0fc7193ac9a55ad14588a2fff4d1.zip
chromium_src-e1e4b6e8810a0fc7193ac9a55ad14588a2fff4d1.tar.gz
chromium_src-e1e4b6e8810a0fc7193ac9a55ad14588a2fff4d1.tar.bz2
Add the anti-clockwise waiting throbber to app mode/popup windows.
BUG=18181 Review URL: http://codereview.chromium.org/160653 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@22537 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/gtk/browser_titlebar.h')
-rw-r--r--chrome/browser/gtk/browser_titlebar.h13
1 files changed, 9 insertions, 4 deletions
diff --git a/chrome/browser/gtk/browser_titlebar.h b/chrome/browser/gtk/browser_titlebar.h
index 98a56ab..29b3cb2 100644
--- a/chrome/browser/gtk/browser_titlebar.h
+++ b/chrome/browser/gtk/browser_titlebar.h
@@ -17,6 +17,7 @@
class BrowserWindowGtk;
class CustomDrawButton;
+class TabContents;
class TabStripGtk;
class BrowserTitlebar : public MenuGtk::Delegate {
@@ -37,7 +38,9 @@ class BrowserTitlebar : public MenuGtk::Delegate {
void UpdateTitle();
// Called by the browser asking us to update the loading throbber.
- void UpdateThrobber(bool is_loading);
+ // |tab_contents| is the tab that is associated with the window throbber.
+ // |tab_contents| can be null.
+ void UpdateThrobber(TabContents* tab_contents);
// On Windows, right clicking in the titlebar background brings up the system
// menu. There's no such thing on linux, so we just show the menu items we
@@ -49,11 +52,12 @@ class BrowserTitlebar : public MenuGtk::Delegate {
// we're showing.
class Throbber {
public:
- Throbber() : current_frame_(0) {}
+ Throbber() : current_frame_(0), current_waiting_frame_(0) {}
// Get the next frame in the animation. The image is owned by the throbber
- // so the caller doesn't need to unref.
- GdkPixbuf* GetNextFrame();
+ // so the caller doesn't need to unref. |is_waiting| is true if we're
+ // still waiting for a response.
+ GdkPixbuf* GetNextFrame(bool is_waiting);
// Reset back to the first frame.
void Reset();
@@ -62,6 +66,7 @@ class BrowserTitlebar : public MenuGtk::Delegate {
static void InitFrames();
int current_frame_;
+ int current_waiting_frame_;
};
// Build the titlebar, the space above the tab